@@ -69,10 +69,14 @@ You can also nest collections as you like, and play for instance with
 ...     )
 ...     assert 6 == george.dice_results["monday"][1]
 """
-
-
 import sheraf
-from ..types import SmallList, LargeList, SmallDict, LargeDict, Set
+
+from ..types import LargeDict
+from ..types import LargeList
+from ..types import Set
+from ..types import SmallDict
+from ..types import SmallList
+from .simples import TypedAttribute
 
 
 class ListAttributeAccessor:
@@ -203,7 +207,7 @@ class ListAttribute(sheraf.attributes.Attribute):
         if not self.attribute:
             return set(list_)
 
-        return set(y for v in list_ for y in self.attribute.index_keys(v))
+        return {y for v in list_ for y in self.attribute.index_keys(v)}
 
     def search_keys(self, value):
         if not self.attribute:
@@ -513,7 +517,7 @@ class SetAttributeAccessor:
         self.mapping.clear()
 
 
-class SetAttribute(sheraf.attributes.simples.TypedAttribute):
+class SetAttribute(TypedAttribute):
     """Attribute mimicking the behavior of :class:`set`.
 
     >>> class Cowboy(sheraf.Model):
@@ -587,7 +591,7 @@ class SetAttribute(sheraf.attributes.simples.TypedAttribute):
         if not self.attribute:
             return set(set_)
 
-        return set(y for v in set_ for y in self.attribute.index_keys(v))
+        return {y for v in set_ for y in self.attribute.index_keys(v)}
 
     def search_keys(self, value):
         if not self.attribute:
